@@ -1,8 +1,8 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-24 10:42:34
-:LastEditTime: 2021-01-06 18:43:31
-:LastEditors: ChenXiaolei
+:LastEditTime: 2021-01-12 08:37:36
+:LastEditors: HuangJingCan
 :Description: StudioBaseHandler
 """
 
@@ -59,7 +59,7 @@ class StudioBaseHandler(BaseCookieHandler):
                 op_result = True
             return op_result
         except:
-            self.logger_error.error(f"添加品台行为日志时异常:{traceback.format_exc()}")
+            self.logger_error.error(f"添加平台行为日志时异常:{traceback.format_exc()}")
             return False
 
     def json_dumps(self, rep_dic):
@@ -148,10 +148,7 @@ class StudioBaseHandler(BaseCookieHandler):
         if origin in allow_origin_list:
             self.set_header("Access-Control-Allow-Origin", origin)
 
-        self.set_header(
-            "Access-Control-Allow-Headers",
-            "Origin,X-Requested-With,Content-Type,Accept,User-Token,Manage-ProductID,Manage-PageID,PYCKET_ID"
-        )
+        self.set_header("Access-Control-Allow-Headers", "Origin,X-Requested-With,Content-Type,Accept,User-Token,Manage-ProductID,Manage-PageID,PYCKET_ID")
         self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS")
         self.set_header("Access-Control-Allow-Credentials", "true")
 
@@ -186,8 +183,7 @@ class StudioBaseHandler(BaseCookieHandler):
         header_product_id = ""
         if self.request.headers.__contains__("Manage-Productid"):
             header_product_id = self.request.headers["Manage-Productid"]
-        product_id = int(
-            header_product_id) if header_product_id.strip() != "" else 0
+        product_id = int(header_product_id) if header_product_id.strip() != "" else 0
         if product_id == 0:
             product_id = int(self.get_param("manage-productid", "0"))
         return product_id
@@ -201,26 +197,21 @@ class StudioBaseHandler(BaseCookieHandler):
         product_info = None
         product_id = self.request_product_id()
         if product_id > 0:
-            product_info = ProductInfoModel(
-                config.get_value("base_manage_context_key")).get_entity_by_id(
-                    product_id)
+            product_info = ProductInfoModel(config.get_value("base_manage_context_key")).get_entity_by_id(product_id)
         return product_info
 
     def get_curr_user_info(self):
         user_info = None
         user_id = self.request_user_id()
         if user_id:
-            user_info = UserInfoModel(
-                self.get_manage_context_key()).get_entity_by_id(user_id)
+            user_info = UserInfoModel(self.get_manage_context_key()).get_entity_by_id(user_id)
         return user_info
 
     def get_base_user_info(self):
         user_info = None
         user_id = self.request_user_id()
         if user_id:
-            user_info = UserInfoModel(
-                config.get_value("base_manage_context_key")).get_entity_by_id(
-                    user_id)
+            user_info = UserInfoModel(config.get_value("base_manage_context_key")).get_entity_by_id(user_id)
         return user_info
 
     def get_is_super(self):
@@ -273,8 +264,7 @@ class StudioBaseHandler(BaseCookieHandler):
         page_cote_id = ""
         page_id = self.request_manage_page_id()
         if not page_id == "":
-            page_cote_id = page_id.split("$")[1] if page_id.__contains__(
-                "$") else ""
+            page_cote_id = page_id.split("$")[1] if page_id.__contains__("$") else ""
         return page_cote_id
 
     def get_dict_page_info_list(self, page_index, page_size, p_dict, total=0):
@@ -322,8 +312,7 @@ class StudioBaseHandler(BaseCookieHandler):
         order = ""
         body_dict = self.request_body_to_dict()
         for item in body_dict:
-            if not item.__contains__("PageIndex") and not item.__contains__(
-                    "PageSize"):
+            if not item.__contains__("PageIndex") and not item.__contains__("PageSize"):
                 # print(body_dict[item])
                 query_method = json.loads(body_dict[item]).get("QueryMethod")
                 query_Value = json.loads(body_dict[item]).get("Value")
@@ -362,8 +351,7 @@ class StudioBaseHandler(BaseCookieHandler):
         :return: 
         :last_editors: HuangJingCan
         """
-        user_dict = UserInfoModel(
-            self.get_manage_context_key()).get_dict_list()
+        user_dict = UserInfoModel(self.get_manage_context_key()).get_dict_list()
         return user_dict
 
     def logout(self, user_id):
@@ -376,11 +364,9 @@ class StudioBaseHandler(BaseCookieHandler):
         if user_id.strip() == "":
             return
         if config.get_value("login_type") == "redis":
-            self.redis_init().hdel(
-                config.get_value("redis_provider_name_user_login"), user_id)
+            self.redis_init().hdel(config.get_value("redis_provider_name_user_login"), user_id)
         else:
-            UserLoginModel(config.get_value("manage_context_key")).del_entity(
-                "UserID=%s", user_id)
+            UserLoginModel(config.get_value("manage_context_key")).del_entity("UserID=%s", user_id)
         self.clear_cookie("UserID")
         self.clear_cookie("UserIDMD5")
         self.clear_cookie("UserToken")
@@ -394,17 +380,13 @@ class StudioBaseHandler(BaseCookieHandler):
         :last_editors: HuangJingCan
         """
         manage_context_key = self.get_manage_context_key()
-        menu_info_list = MenuInfoModel(manage_context_key).get_list(
-            f"ApiPath LIKE '%{api_path}%'")
+        menu_info_list = MenuInfoModel(manage_context_key).get_list(f"ApiPath LIKE '%{api_path}%'")
         if not menu_info_list:
             return False
         if len([i for i in menu_info_list if i.IsPower == 0]) > 0:
             return True
-        role_user_list = RoleUserModel(manage_context_key).get_list(
-            "UserID=%s", params=self.request_user_id())
-        role_power_list = RolePowerModelEx(
-            manage_context_key).get_role_power_list(
-                [i.RoleID for i in role_user_list])
+        role_user_list = RoleUserModel(manage_context_key).get_list("UserID=%s", params=self.request_user_id())
+        role_power_list = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
         cote_list = [i for i in role_power_list if i.CoteID == cote_id]
         menu_list = [i.MenuID for i in menu_info_list]
         if len([i for i in cote_list if menu_list.__contains__(i.MenuID)]) > 0:
@@ -435,36 +417,25 @@ def login_filter(is_need_login=True, optional_params=None):
     """
     def check_login(handler):
         def wrapper(self, **args):
-            base_manage_context_key = config.get_value(
-                "base_manage_context_key")
+            base_manage_context_key = config.get_value("base_manage_context_key")
             # 获取头部信息
             header_token = self.request_header_token()
-            user_id = header_token["UserID"] if header_token.__contains__(
-                "UserID") else ""
-            user_token = header_token[
-                "UserToken"] if header_token.__contains__("UserToken") else ""
-            user_id_md5 = header_token[
-                "UserIDMD5"] if header_token.__contains__("UserIDMD5") else ""
-            if user_id.strip() == "" or user_token.strip(
-            ) == "" or user_id_md5.strip() == "":
+            user_id = header_token["UserID"] if header_token.__contains__("UserID") else ""
+            user_token = header_token["UserToken"] if header_token.__contains__("UserToken") else ""
+            user_id_md5 = header_token["UserIDMD5"] if header_token.__contains__("UserIDMD5") else ""
+            if user_id.strip() == "" or user_token.strip() == "" or user_id_md5.strip() == "":
                 return self.reponse_common("NoLogin", "未登录")
-            if is_need_login and CryptoHelper.md5_encrypt(
-                    user_id,
-                    config.get_value("login_encrypt_key")) != user_id_md5:
+            if is_need_login and CryptoHelper.md5_encrypt(user_id, config.get_value("login_encrypt_key")) != user_id_md5:
                 return self.reponse_common("NoLogin", "未登录")
 
             # 登陆日志判断，Redis还是MySQL
             if config.get_value("login_type") == "redis":
-                redis_user_login = self.redis_init().hget(
-                    config.get_value("redis_provider_name_user_login"),
-                    user_id)
+                redis_user_login = self.redis_init().hget(config.get_value("redis_provider_name_user_login"), user_id)
                 user_login = {}
                 if redis_user_login:
                     user_login = json.loads(redis_user_login)
 
-                if not user_login or TimeHelper.format_time_to_datetime(
-                        user_login["ExpireTime"]
-                ) < TimeHelper.get_now_datetime():
+                if not user_login or TimeHelper.format_time_to_datetime(user_login["ExpireTime"]) < TimeHelper.get_now_datetime():
                     if not is_need_login:
                         return
                     return self.reponse_common("UserExpire", "用户已过期，请重新登录")
@@ -473,23 +444,17 @@ def login_filter(is_need_login=True, optional_params=None):
                         return
                     return self.reponse_common("DeviceExpire", "用户在其他终端登录")
 
-                curr_user_info = UserInfoModel(
-                    config.get_value("manage_context_key")).get_entity_by_id(
-                        user_id)
+                curr_user_info = UserInfoModel(config.get_value("manage_context_key")).get_entity_by_id(user_id)
                 if curr_user_info.IsLock == 1:
                     return self.reponse_common("UserLimit", "用户已被锁，请联系管理员")
 
-                user_login["ExpireTime"] = TimeHelper.add_hours_by_format_time(
-                    hour=config.get_value("login_expire"))
-                self.redis_init().hset(
-                    config.get_value("redis_provider_name_user_login"),
-                    user_id, self.json_dumps(user_login))
+                user_login["ExpireTime"] = TimeHelper.add_hours_by_format_time(hour=config.get_value("login_expire"))
+                self.redis_init().hset(config.get_value("redis_provider_name_user_login"), user_id, self.json_dumps(user_login))
             else:
                 user_login_model = UserLoginModel(base_manage_context_key)
                 user_login = user_login_model.get_entity_by_id(user_id)
 
-                if not user_login or TimeHelper.format_time_to_datetime(
-                        user_login.ExpireTime) < TimeHelper.get_now_datetime():
+                if not user_login or TimeHelper.format_time_to_datetime(user_login.ExpireTime) < TimeHelper.get_now_datetime():
                     if not is_need_login:
                         return
                     return self.reponse_common("UserExpire", "用户已过期，请重新登录")
@@ -500,27 +465,21 @@ def login_filter(is_need_login=True, optional_params=None):
 
                 manage_context_key = self.get_manage_context_key()
 
-                curr_user_info = UserInfoModel(
-                    manage_context_key).get_entity_by_id(user_id)
+                curr_user_info = UserInfoModel(manage_context_key).get_entity_by_id(user_id)
                 if not curr_user_info:
                     return self.reponse_common("UserNoExist", "用户不存在，请重新登录")
                 if curr_user_info.IsLock == 1:
                     return self.reponse_common("UserLimit", "用户已被锁，请联系管理员")
 
                 if base_manage_context_key != manage_context_key:
-                    curr_user_info = UserInfoModel(
-                        base_manage_context_key).get_entity_by_id(user_id)
+                    curr_user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
                     if not curr_user_info:
-                        return self.reponse_common("UserNoExist",
-                                                   "用户不存在，请重新登录")
+                        return self.reponse_common("UserNoExist", "用户不存在，请重新登录")
                     if curr_user_info.IsLock == 1:
                         return self.reponse_common("UserLimit", "用户已被锁，请联系管理员")
 
-                user_login.ExpireTime = TimeHelper.add_hours_by_format_time(
-                    hour=config.get_value("login_expire"))
-                user_login_model.update_table(
-                    f"ExpireTime='{user_login.ExpireTime}'", "UserID=%s",
-                    user_login.UserID)
+                user_login.ExpireTime = TimeHelper.add_hours_by_format_time(hour=config.get_value("login_expire"))
+                user_login_model.update_table(f"ExpireTime='{user_login.ExpireTime}'", "UserID=%s", user_login.UserID)
 
             return handler(self, **args)
 
@@ -543,8 +502,7 @@ def power_filter(is_check_power=True, optional_params=None):
                     if api_path.strip() == "":
                         return self.reponse_common("NoPower", "没有权限")
                     page_id = self.request_manage_page_id()
-                    cote_id = page_id.split("$")[1] if page_id.__contains__(
-                        "$") else ""
+                    cote_id = page_id.split("$")[1] if page_id.__contains__("$") else ""
                     if not self.check_power_menu(api_path, cote_id):
                         return self.reponse_common("NoPower", "没有权限")
 
