@@ -1,8 +1,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-03-24 19:48:05
-:LastEditTime: 2020-12-25 10:04:18
-:LastEditors: ChenXiaolei
+:LastEditTime: 2021-02-06 15:50:20
+:LastEditors: HuangJingCan
 :Description: 
 """
 from seven_studio.handlers.studio_base import *
@@ -130,18 +130,18 @@ class LoginPlatformHandler(StudioBaseHandler):
 
             is_super = user_info_curr.IsSuper == 1 or user_info.IsSuper == 1
 
-        if is_platform and not is_super:
-            role_user_list = RoleUserModel(manage_context_key).get_list("UserID=%s", params=user_info.UserID)
-            if len(role_user_list) == 0:
-                invoke_result.ResultCode = "AccountLock"
-                invoke_result.ResultMessage = "对不起该账号没有平台管理权限"
-                return invoke_result
+        # if is_platform and not is_super:
+        #     role_user_list = RoleUserModel(manage_context_key).get_list("UserID=%s", params=user_info.UserID)
+        #     if len(role_user_list) == 0:
+        #         invoke_result.ResultCode = "AccountLock"
+        #         invoke_result.ResultMessage = "对不起该账号没有平台管理权限"
+        #         return invoke_result
 
-            role_power_list = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
-            if not [i for i in role_power_list if i.MenuID == config.get_value("menu_id_platform")]:
-                invoke_result.ResultCode = "AccountLock"
-                invoke_result.ResultMessage = "对不起该账号没有平台管理权限"
-                return invoke_result
+        #     role_power_list = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
+        #     if not [i for i in role_power_list if i.MenuID == config.get_value("menu_id_platform")]:
+        #         invoke_result.ResultCode = "AccountLock"
+        #         invoke_result.ResultMessage = "对不起该账号没有平台管理权限"
+        #         return invoke_result
 
         user_info.FaildLoginCount = 0
         user_info.LoginDate = TimeHelper.get_now_datetime()
