@@ -1,9 +1,9 @@
 """
-@Author: HuangJingCan
-@Date: 2020-03-17 16:12:54
-@LastEditTime: 2020-12-10 14:15:03
-@LastEditors: ChenXiaolei
-@Description: 文件操作相关接口
+:Author: HuangJingCan
+:Date: 2020-03-17 16:12:54
+:LastEditTime: 2020-12-25 10:04:37
+:LastEditors: ChenXiaolei
+:Description: 文件操作相关接口
 """
 from seven_studio.handlers.studio_base import *
 
@@ -18,16 +18,16 @@ from seven_studio.libs.file.ks3 import *
 
 class GetStoragePathListHandler(StudioBaseHandler):
     """
-    @description: 获取存储配置列表
+    :description: 获取存储配置列表
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: 获取存储配置列表
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取存储配置列表
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_storage_path_model = FileStoragePathModel(self.get_file_context_key())
         page_index = self.get_page_index()
@@ -41,19 +41,19 @@ class GetStoragePathListHandler(StudioBaseHandler):
 
 class GetStoragePathDataHandler(StudioBaseHandler):
     """
-    @description: 获取存储配置
-    @param {type} 
-    @return: 
-    @last_editors: HuangJingCan
+    :description: 获取存储配置
+    :param {type} 
+    :return: 
+    :last_editors: HuangJingCan
     """
     @login_filter(True)
     @power_filter(True)
     def get_async(self):
         """
-        @description: 获取存储配置
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取存储配置
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_storage_path_model = FileStoragePathModel(self.get_file_context_key())
         p_dict = file_storage_path_model.get_dict_list("", "FileStoragePathID,StoragePathName")
@@ -63,16 +63,16 @@ class GetStoragePathDataHandler(StudioBaseHandler):
 
 class SaveStoragePathHandler(StudioBaseHandler):
     """
-    @description: 保存存储配置
+    :description: 保存存储配置
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: 保存存储配置
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 保存存储配置
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         # 获取参数
         file_storage_path_id = self.get_param("FileStoragePathID")
@@ -119,16 +119,16 @@ class SaveStoragePathHandler(StudioBaseHandler):
 
 class DeleteStoragePathHandler(StudioBaseHandler):
     """
-    @description: 删除存储配置
+    :description: 删除存储配置
     """
     @login_filter(True)
     @power_filter(True)
     def get_async(self):
         """
-        @description: 删除存储配置
-        @param id：id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除存储配置
+        :param id：id
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_storage_path_id = self.get_param("FileStoragePathID")
         if file_storage_path_id == "":
@@ -141,16 +141,16 @@ class DeleteStoragePathHandler(StudioBaseHandler):
 
 class GetResourceListHandler(StudioBaseHandler):
     """
-    @description: 获取文件配置列表
+    :description: 获取文件配置列表
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: 获取文件配置列表
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取文件配置列表
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_resource_model = FileResourceModel(self.get_file_context_key())
         page_index = self.get_page_index()
@@ -164,16 +164,16 @@ class GetResourceListHandler(StudioBaseHandler):
 
 class GetResourceInfoHandler(StudioBaseHandler):
     """
-    @description: 获取文件配置
+    :description: 获取文件配置
     """
     @login_filter(True)
     @power_filter(True)
     def get_async(self):
         """
-        @description: 获取文件配置
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取文件配置
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_resource_model = FileResourceModel(self.get_file_context_key())
         p_dict = file_resource_model.get_dict_by_id(self.get_page_cote_id())
@@ -183,16 +183,16 @@ class GetResourceInfoHandler(StudioBaseHandler):
 
 class SaveResourceHandler(StudioBaseHandler):
     """
-    @description: 保存文件配置
+    :description: 保存文件配置
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: 保存文件配置
-        @param id：id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 保存文件配置
+        :param id：id
+        :return: 
+        :last_editors: HuangJingCan
         """
         # 获取参数
         file_resource_id = self.get_param("FileResourceID")
@@ -227,16 +227,16 @@ class SaveResourceHandler(StudioBaseHandler):
 
 class DeleteResourceHandler(StudioBaseHandler):
     """
-    @description: 删除资源
+    :description: 删除资源
     """
     @login_filter(True)
     @power_filter(True)
     def get_async(self):
         """
-        @description: 删除资源
-        @param id：id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除资源
+        :param id：id
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_resource_id = self.get_param("FileResourceID")
         if file_resource_id == "":
@@ -249,16 +249,16 @@ class DeleteResourceHandler(StudioBaseHandler):
 
 class GetRestrictListHandler(StudioBaseHandler):
     """
-    @description: 获取上传限制
+    :description: 获取上传限制
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: 获取上传限制
-        @param {type} 
-        @return: reponse_json_success
-        @last_editors: HuangJingCan
+        :description: 获取上传限制
+        :param {type} 
+        :return: reponse_json_success
+        :last_editors: HuangJingCan
         """
         condition = ""
         con, order = self.get_condition_by_body()
@@ -285,16 +285,16 @@ class GetRestrictListHandler(StudioBaseHandler):
 
 class SaveRestrictHandler(StudioBaseHandler):
     """
-    @description: SaveRestrict
+    :description: SaveRestrict
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: SaveRestrict
-        @param id：id
-        @return: reponse_json_success
-        @last_editors: HuangJingCan
+        :description: SaveRestrict
+        :param id：id
+        :return: reponse_json_success
+        :last_editors: HuangJingCan
         """
         # 获取参数
         file_restrict_id = self.get_param("FileRestrictID")
@@ -373,16 +373,16 @@ class SaveRestrictHandler(StudioBaseHandler):
 
 class DeleteRestrictHandler(StudioBaseHandler):
     """
-    @description: DeleteRestrict
+    :description: DeleteRestrict
     """
     @login_filter(True)
     @power_filter(True)
     def get_async(self):
         """
-        @description: 删除
-        @param id：id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除
+        :param id：id
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_restrict_id = self.get_param("FileRestrictID")
         if file_restrict_id == "":
@@ -395,16 +395,16 @@ class DeleteRestrictHandler(StudioBaseHandler):
 
 class GetWaterImageListHandler(StudioBaseHandler):
     """
-    @description: 获取水印图片列表
+    :description: 获取水印图片列表
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: 获取水印图片列表
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取水印图片列表
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_water_image_model = FileWaterImageModel(self.get_file_context_key())
         page_index = self.get_page_index()
@@ -418,16 +418,16 @@ class GetWaterImageListHandler(StudioBaseHandler):
 
 class GetWaterImageDataHandler(StudioBaseHandler):
     """
-    @description: 获取水印图片
+    :description: 获取水印图片
     """
     @login_filter(True)
     @power_filter(True)
     def get_async(self):
         """
-        @description: 获取水印图片
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取水印图片
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_water_image_model = FileWaterImageModel(self.get_file_context_key())
         p_dict = file_water_image_model.get_dict_list(field="WaterImageID,WaterName")
@@ -437,18 +437,18 @@ class GetWaterImageDataHandler(StudioBaseHandler):
 
 class SaveWaterImageHandler(StudioBaseHandler):
     """
-    @description: 保存图片水印
+    :description: 保存图片水印
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: 保存图片水印
-        @param WaterImageID：水印图片id 
-        @param WaterImagePath：水印图片路径
-        @param WaterName：水印图片名称
-        @return: reponse_json_success
-        @last_editors: HuangJingCan
+        :description: 保存图片水印
+        :param WaterImageID：水印图片id 
+        :param WaterImagePath：水印图片路径
+        :param WaterName：水印图片名称
+        :return: reponse_json_success
+        :last_editors: HuangJingCan
         """
         # 获取参数
         water_image_id = self.get_param("WaterImageID")
@@ -481,16 +481,16 @@ class SaveWaterImageHandler(StudioBaseHandler):
 
 class DeleteWaterImageHandler(StudioBaseHandler):
     """
-    @description: 删除水印图
+    :description: 删除水印图
     """
     @login_filter(True)
     @power_filter(True)
     def get_async(self):
         """
-        @description: 删除
-        @param WaterImageID：主键id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除
+        :param WaterImageID：主键id
+        :return: 
+        :last_editors: HuangJingCan
         """
         water_image_id = self.get_param("WaterImageID")
         if water_image_id == "":
@@ -503,16 +503,16 @@ class DeleteWaterImageHandler(StudioBaseHandler):
 
 class GetHistoryListHandler(StudioBaseHandler):
     """
-    @description: 获取文件历史
+    :description: 获取文件历史
     """
     @login_filter(True)
     @power_filter(True)
     def post_async(self):
         """
-        @description: 获取文件历史
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取文件历史
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_history_model = FileHistoryModel(self.get_file_context_key())
         page_index = self.get_page_index()
@@ -526,16 +526,16 @@ class GetHistoryListHandler(StudioBaseHandler):
 
 class DeleteHistoryHandler(StudioBaseHandler):
     """
-    @description: 删除文件历史记录
+    :description: 删除文件历史记录
     """
     @login_filter(True)
     @power_filter(True)
     def get_async(self):
         """
-        @description: 删除文件历史记录
-        @param FileHistoryID：主键id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除文件历史记录
+        :param FileHistoryID：主键id
+        :return: 
+        :last_editors: HuangJingCan
         """
         file_history_id = self.get_param("FileHistoryID")
         if file_history_id == "":
