@@ -1,8 +1,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-15 09:56:24
-:LastEditTime: 2020-12-10 17:19:53
-:LastEditors: ChenXiaolei
+:LastEditTime: 2021-02-03 16:38:43
+:LastEditors: HuangJingCan
 :Description: 权限角色栏目相关
 """
 
@@ -68,7 +68,8 @@ class PowerModel():
         menu_item_list = []
 
         # 平台管理权限
-        menu_info_list_plat = [i for i in menu_info_list if i.MenuType == 1 and i.MenuID == config.get_value("menu_id_platform")]
+        # menu_info_list_plat = [i for i in menu_info_list if i.MenuType == 1 and i.MenuID == config.get_value("menu_id_platform")]
+        menu_info_list_plat = [i for i in menu_info_list if i.MenuType == 1]
         for menu_info in menu_info_list_plat:
             curr_menu_item_dto = PowerMenuInfoDto()
             curr_menu_item_dto.MenuID = menu_info.MenuID
@@ -397,9 +398,9 @@ class PowerModel():
         menu_role_list = []
         rowle_power_list = RolePowerModelEx(self.db_connect_key).get_list("MenuID=%s", params=menu_id)
         if rowle_power_list:
-            role_info_list = RoleInfoModel(self.db_connect_key).get_list("RoleID IN ("+','.join("'"+str(item.RoleID)+"'" for item in rowle_power_list)+")")
-            role_user_list = RoleUserModel(self.db_connect_key).get_list("RoleID IN ("+','.join("'"+str(item.RoleID)+"'" for item in rowle_power_list)+")")
-            user_info_list = UserInfoModel(self.db_connect_key).get_list("UserID IN ("+','.join("'"+str(item.UserID)+"'" for item in role_user_list)+")")
+            role_info_list = RoleInfoModel(self.db_connect_key).get_list("RoleID IN (" + ','.join("'" + str(item.RoleID) + "'" for item in rowle_power_list) + ")")
+            role_user_list = RoleUserModel(self.db_connect_key).get_list("RoleID IN (" + ','.join("'" + str(item.RoleID) + "'" for item in rowle_power_list) + ")")
+            user_info_list = UserInfoModel(self.db_connect_key).get_list("UserID IN (" + ','.join("'" + str(item.UserID) + "'" for item in role_user_list) + ")")
             for curr_role_info in role_info_list:
                 curr_user_info_list = [i for j in [i.UserID for i in role_user_list if i.RoleID == curr_role_info.RoleID] for i in user_info_list if j in i.UserID]
                 info = {}
@@ -453,7 +454,7 @@ class PowerModel():
         result = DictUtil.auto_mapper(RoleUserDto(), role_info.__dict__)
         result.RoleUserIds = user_id_list
         result.RoleMenuIds = menu_id_list
-        result.IsAdd=is_add
+        result.IsAdd = is_add
         return result
 
     def add_role_user(self, role_id, user_id_list):
@@ -500,8 +501,8 @@ class PowerModel():
         base_user_info_model = UserInfoModel(config.get_value("base_manage_context_key"))
         role_id_list = [i for i in role_id_list if i != ""]
         product_id_list = [i for i in product_id_list if i != ""]
-        update_field=["IsSuper","Account","Email","LoginIP","PasswordQuestion","PasswordAnswer","IsLock","FaildLoginCount","FaildQuestionCount","UserName","NickName","JobNo","Avatar","LoginDate","Phone","PersonalitySignature","ChiefUserID"]
-        
+        update_field = ["IsSuper", "Account", "Email", "LoginIP", "PasswordQuestion", "PasswordAnswer", "IsLock", "FaildLoginCount", "FaildQuestionCount", "UserName", "NickName", "JobNo", "Avatar", "LoginDate", "Phone", "PersonalitySignature", "ChiefUserID"]
+
         if change_pw:
             update_field.append("Password")
         if is_add:
@@ -514,15 +515,15 @@ class PowerModel():
                 base_user_info_model.add_entity(user_info)
                 user_info_model.add_entity(user_info, True)
             if change_pw:
-                user_info.Password = UserInfoModelEx().sign_password(password,user_info.UserID)
+                user_info.Password = UserInfoModelEx().sign_password(password, user_info.UserID)
             else:
                 user_info.Password = UserInfoModelEx().sign_password(config.get_value("default_password"))
-            user_info_model.update_entity(user_info,field_list=update_field)
+            user_info_model.update_entity(user_info, field_list=update_field)
             base_user_info_model.update_table("Password=%s", "UserID=%s", params=[user_info.Password, user_info.UserID])
         else:
             if change_pw:
-                user_info.Password = UserInfoModelEx().sign_password(password,user_info.UserID)
-            user_info_model.update_entity(user_info,field_list=update_field)
+                user_info.Password = UserInfoModelEx().sign_password(password, user_info.UserID)
+            user_info_model.update_entity(user_info, field_list=update_field)
             base_user_info_model.update_table("Password=%s", "UserID=%s", params=[user_info.Password, user_info.UserID])
 
         if len(role_id_list) > 0:
